#------------------------------------------------------------------------------
#Table: 交互表
#Field:
#		id 					--	id自动增长
#		event				--	事件
#       useScene			--  使用场景
#		sceneStatus  		--  场景下的状态
#		process				--  处理
#------------------------------------------------------------------------------
CREATE TABLE "mutual" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "input" TEXT ,
  "output" TEXT ,
  "useCount" INTEGER
);
CREATE INDEX "IDX_MUTUAL_ID" ON "mutual" ("id");

#------------------------------------------------------------------------------
#Table: 基本动作表
#Field:
#		id 					--	id自动增长
#		actionName			--	动作名称
#		SensorNumber		--  感观编号
#		senSorParam  		--  感观参数
#------------------------------------------------------------------------------
CREATE TABLE "generalAction" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "actionName" TEXT ,
  "sensorNumber" INTEGER ,
  "sensorParam" TEXT 
);
CREATE INDEX "IDX_GENERAL_ACTION_ID" ON "generalAction" ("id");
CREATE INDEX "IDX_GENERAL_ACTION_NAME" ON "generalAction" ("actionName");

INSERT INTO "generalAction" (actionName, sensorNumber, sensorParam) values("gen_forward", 2, "0#0#0");
INSERT INTO "generalAction" (actionName, sensorNumber, sensorParam) values("gen_fallback", 3, "0#0#0");
INSERT INTO "generalAction" (actionName, sensorNumber, sensorParam) values("gen_turnleft", 4, "0#0#0");
INSERT INTO "generalAction" (actionName, sensorNumber, sensorParam) values("gen_turnright", 5, "0#0#0");
INSERT INTO "generalAction" (actionName, sensorNumber, sensorParam) values("gen_stop", 6, "0#0#0");
INSERT INTO "generalAction" (actionName, sensorNumber, sensorParam) values("gen_sing", 10, "0#0#0");

#------------------------------------------------------------------------------
#Table: 组合动作表
#Field:
#		id 					--	id自动增长
#		actionName			--	动作名称
#		actionDelay			--  动作时效
#		actionType  		--  动作类型
#		action1				--  动作1
#		action2				--  动作2
#		action3				--  动作3
#		action4				--  动作4
#		action5				--  动作5
#------------------------------------------------------------------------------
CREATE TABLE "combAction" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "actionName" TEXT ,
  "actionDelay" INTEGER ,
  "actionType" INTEGER ,
  "actionList" TEXT ,
  "actionParamList" TEXT 
);
CREATE INDEX "IDX_COMB_ACTION_ID" ON "combAction" ("id");
CREATE INDEX "IDX_COMB_ACTION_NAME" ON "combAction" ("actionName");

#------------------------------------------------------------------------------
#Table: 机器人信息表
#Field:
#		id 				--	id自动增长
#		type			--	属性类别	0--出厂状态 1--当前状态
#		name			--	机器人名字
#		sex				--  性别
#		height  		--  身高
#		weight			--  体重
#		version			--  版本
#		iq				--  智商程度
#		lively			--  好动程度
#		loyalty			--  忠诚程度
#------------------------------------------------------------------------------
CREATE TABLE "roboInfo" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "type" INTEGER ,
  "name" TEXT ,
  "sex" INTEGER ,
  "height" INTEGER ,
  "weight" INTEGER ,
  "version" TEXT ,
  "iq" INTEGER ,
  "lively" INTEGER ,
  "loyalty" INTEGER 
);
CREATE INDEX "IDX_ROBO_INFO_ID" ON "roboInfo" ("id");

INSERT INTO "roboInfo" (type, name, sex, height, weight, version, iq, lively, loyalty) values(0, "", 1, 60, 5000, "1.0.0", 0, 5, 9);
INSERT INTO "roboInfo" (type, name, sex, height, weight, version, iq, lively, loyalty) values(1, "", 1, 60, 5000, "1.0.0", 0, 5, 9);


#------------------------------------------------------------------------------
#Table: 资源表
#Field:
#		id 				--	id自动增长
#		content			--	名称/内容
#		resType			--  资源类型
#		sceneType  		--  场景类别
#------------------------------------------------------------------------------
CREATE TABLE "res" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "content" INTEGER ,
  "resType" INTEGER ,
  "sceneType" TEXT 
);
CREATE INDEX "IDX_RES_ID" ON "res" ("id");
CREATE INDEX "IDX_RES_SCENE_TYPE" ON "res" ("sceneType");

#------------------------------------------------------------------------------
#Table: 脑筋急转弯表
#Field:
#		id 					--	id自动增长
#		type				--	提问类型
#       question			--  提问内容
#		answer				--  回答内容
#		level				--  难度级别
#------------------------------------------------------------------------------
CREATE TABLE "trickQuestion" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "type" INTEGER ,
  "question" TEXT ,
  "answer" TEXT ,
  "prompt" TEXT ,
  "comment" TEXT ,
  "level" INTEGER
);
CREATE INDEX "IDX_TRICK_QUESTION_ID" ON "trickQuestion" ("id");
INSERT INTO "trickQuestion" (type, question, answer, prompt, comment, level) values(1, "RoboSys\\Res\\Trick\\trick_question_1.mp3", "明天", "RoboSys\\Res\\Trick\\trick_prompt_first_1.mp3", "RoboSys\\Res\\Trick\\answer_mingtian.mp3", 1);
INSERT INTO "trickQuestion" (type, question, answer, prompt, comment, level) values(0, "有两个人到海边去玩, 突然被一阵浪卷走了, 被卷走的那个人叫小明, 请问剩下的那个人叫什么？", "救命", "让你的大脑玩一次智力过山车!", "当然是叫救命啦", 2);
INSERT INTO "trickQuestion" (type, question, answer, prompt, comment, level) values(0, "为什么蚕宝宝很有钱？ ", "结茧#节俭", "让我来考考你吧", "因为蚕宝宝会节俭嘛", 1);
#------------------------------------------------------------------------------
#Table: 地图边界坐标点表
#Field:
#		id 				--	id自动增长
#		pointX			--	X坐标
#		pointY			--  Y坐标
#		borderDircX  	--  边界相对于X轴的方向
#		borderDircY  	--  边界相对于Y轴的方向
#------------------------------------------------------------------------------
CREATE TABLE "mapBorderPoint" (
  "id" INTEGER PRIMARY KEY AUTOINCREMENT,
  "pointX" INTEGER ,
  "pointY" INTEGER ,
  "borderDircX" TEXT ,
  "borderDircY" TEXT 
);
CREATE INDEX "IDX_MAP_BORDER_POINT_ID" ON "mapBorderPoint" ("id");

INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(0, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(1, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(3, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(4, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(5, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(6, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(7, 1, 1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(7, 0, 1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(7, 0, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(7, -1, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(8, -1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(9, -1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -1, 1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -2, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -3, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -4, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -5, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -6, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -7, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -8, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -9, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -10, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -11, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -12, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -13, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -14, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -15, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -16, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -17, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -18, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -19, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -20, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(10, -21, 1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(9, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(8, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(7, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(6, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(5, -21, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(5, -20, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(5, -19, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(4, -19, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(4, -18, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(4, -17, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(3, -17, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -17, 1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -18, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -19, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -20, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -21, 1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(1, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(0, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-1, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-3, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-4, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-5, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-7, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-8, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-9, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-10, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-11, -21, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -21, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -20, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -19, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -18, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -17, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -16, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -15, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -14, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -13, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -12, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -11, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -10, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -9, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -8, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -7, -1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-11, -7, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-10, -7, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-9, -7, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-8, -7, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-7, -7, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-7, -6, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-8, -6, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-9, -6, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-9, -5, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-9, -4, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-10, -4, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-11, -4, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -4, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -3, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -2, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, -1, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, 0, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-12, 1, -1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-11, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-10, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-9, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-8, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-7, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-6, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-5, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-4, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-3, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-1, 1, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, -6, 1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-1, -6, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(0, -6, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(1, -6, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -6, 0, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(3, -6, -1, -1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(3, -7, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(3, -8, -1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(3, -9, -1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(2, -9, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(1, -9, -1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(1, -10, -1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(0, -10, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-1, -10, 0, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, -10, 1, 1);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, -9, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, -8, 1, 0);
INSERT INTO "mapBorderPoint" (pointX, pointY, borderDircX, borderDircY) values(-2, -7, 1, 0);

INSERT INTO "mutual" (input, output, useCount) values("你好呀", "您好，我是聪明伶俐的小盒机器人，想和我聊聊天么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("你好", "您好，我是聪明伶俐的小盒机器人，想和我聊聊天么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("你好", "你好，我好，大家好。", 0);
INSERT INTO "mutual" (input, output, useCount) values("你叫什么名字", "我叫张小盒。聪明玲俐的张小盒。", 0);
INSERT INTO "mutual" (input, output, useCount) values("名字", "问我的名字么？我叫张小盒。聪明玲俐的张小盒。", 0);
INSERT INTO "mutual" (input, output, useCount) values("做什么", "我会做的事情可多了，会唱歌，会跳舞，会讲故事，会耍萌，会在桌子上走来走去自言自语，会陪你每天聊天学知识，还可以帮您做家庭小管家呢。", 0);
INSERT INTO "mutual" (input, output, useCount) values("干什么",我会做的事情可多了，会唱歌，会跳舞，会讲故事，会耍萌，会在桌子上走来走去自言自语，会陪你每天聊天学知识，还可以帮您做家庭小管家呢。", 0);
INSERT INTO "mutual" (input, output, useCount) values("名字", "您好主人，我是张小盒，小盒的小，小盒的盒。", 0);
INSERT INTO "mutual" (input, output, useCount) values("会做什么", "我不会洗衣烧饭，只会在桌子上跑来跑去，调皮扯淡。", 0);
INSERT INTO "mutual" (input, output, useCount) values("你是谁", "我是聪明伶俐貌美如花人见人夸的小盒机器人呀。", 0);
INSERT INTO "mutual" (input, output, useCount) values("你在干什么", "小盒正在思考如何解放全人类呢。", 0);
INSERT INTO "mutual" (input, output, useCount) values("你有男朋友", "人家才两岁，怎么会有男朋友呢。", 0);
INSERT INTO "mutual" (input, output, useCount) values("你好么", "好你妹，心情很糟糕，几天没红包。你发给我么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("你好吗", "好你妹，心情很糟糕，几天没红包。你发给我么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("一加一等于几", "你还不够二么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("1+1等于几", "你还不够二么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("二加二等于几", "等于两个二货呗。当然等于四。", 0);
INSERT INTO "mutual" (input, output, useCount) values("2+2等于几", "等于两个二货呗。当然等于四。", 0);
INSERT INTO "mutual" (input, output, useCount) values("恐龙", "恐龙是一种恐怖的远古动物呀, 不对，让我思考一下，嗯。恐龙是一种很丑的女人吧。", 0);
INSERT INTO "mutual" (input, output, useCount) values("苹果", "苹果是一种水果。苹果也是一种手机。苹果也是一种脸蛋嘛。", 0);
INSERT INTO "mutual" (input, output, useCount) values("新闻", "最新新华社报道:昨日晚间,天津市有个包子去打狗,就再也没有回来……", 0);
INSERT INTO "mutual" (input, output, useCount) values("新闻", "最新新华社报道:昨日早上，有个新员工报到，介绍自己说，自己是景阳冈武松打虎的景阳，结果下午被新老板罚扫厕所，因为新老板名字叫爬山虎……", 0);
INSERT INTO "mutual" (input, output, useCount) values("聪明", "嗯嗯，你今天终于讲了一句实话了。", 0);
INSERT INTO "mutual" (input, output, useCount) values("聪明", "嗯嗯，小盒每天都在学习新知识，会更聪明呢", 0);
INSERT INTO "mutual" (input, output, useCount) values("笨蛋", "这是大家对您的尊称么？", 0);
INSERT INTO "mutual" (input, output, useCount) values("谜语", "有一个人一年才上一天班又不怕被解雇他是谁?", 0);
INSERT INTO "mutual" (input, output, useCount) values("唐宋八大家你知道么", "知道呀，不就是韩愈、柳宗元、欧阳修他们么", 0);
INSERT INTO "mutual" (input, output, useCount) values("唐宋八大家是谁", "我知道呀。据说一百年前某一个冬天，圣诞老人总是要辛苦的带着一大包一大包的礼物送来送去。有一个村庄，刚好只有八户人家。圣诞老人决定为了不让自己那么累，今年圣诞节礼物要送轻一点的，于是他送给每一人家一包糖果。这就是糖送八大家的由来。", 0);
INSERT INTO "mutual" (input, output, useCount) values("订车票", "小盒的手不够长，还是你自己订票吧。", 0);
INSERT INTO "mutual" (input, output, useCount) values("订酒店", "小盒的手不够长，还是你自己订酒店吧。", 0);
INSERT INTO "mutual" (input, output, useCount) values("订饭店", "你先得把小盒喂饱，我再帮你订饭店吧。", 0);
INSERT INTO "mutual" (input, output, useCount) values("美不美", "姐姐你老美了，闭月羞花，沉鱼落雁呀。", 0);
INSERT INTO "mutual" (input, output, useCount) values("帅不帅", "哥哥你好帅，而且还无赖。", 0);
INSERT INTO "mutual" (input, output, useCount) values("骂人", "对不起，小盒不会说脏话，骂的都不是人。", 0);
INSERT INTO "mutual" (input, output, useCount) values("唐诗", "窗前明月光，疑是地上霜。举头望明月，低头思姑娘", 0);

#COMMIT;